==> ts-pfsense_1.04-01.tar.gz: ts-pfsense/tslogupload.php <==
<?php
/**
 *
 * Copyright(c) 2006-2016 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

$content    = shell_exec("%clog% $argv[1]");
//$content    = shell_exec("$(which clog) $argv[1]");
shell_exec('/usr/bin/logger -p local0.info "ThreatSTOP log upload"');
$startpos = strrpos("ThreatSTOP log upload", $content);
if ($startpos) {
	$content = substr($content, $startpos);
}
$ip      = 'ssl://threatstop.com';
$host    = 'threatstop.com';
$md5     = md5($content);
$len     = strlen($content);
//echo "$md5 $len\n";
$sp = fsockopen($ip, 443, $errno, $errstr, 10);

if (!$sp) {
	die("error: $errstr ($errno)" . "\r\n");
}

$boundary = str_repeat('-', 10) . time();

$body = '--' . $boundary . "\r\n";
$body .= "Content-Disposition: form-data; name=\"md5_client\"\r\n\r\n";
$body .= $md5."\r\n";
$body .= '--' . $boundary . "\r\n";
$body .= "Content-Disposition: form-data; name=\"upfile_size\"\r\n\r\n";
$body .= "$len\r\n";
$body .= '--' . $boundary . "\r\n";
//$body .= "Content-Disposition: form-data; name=\"fw_ip\"\r\n\r\n";
//$body .= $ip"\r\n";
//$body .= '--' . $boundary . "\r\n";
$body .= "Content-Disposition: form-data; name=\"upfile\"; filename=\"log\"\r\n";
$body .= "Content-Type: text/plain\r\n";
$body .= "Content-Transfer-Encoding: binary\r\n\r\n";
$body .= $content . "\r\n";
$body .= "--$boundary--\r\n";

$query  = 'POST /cgi-bin/logupload.pl HTTP/1.1' . "\r\n";
$query .= 'HOST: ' . $host . "\r\n";
$query .= 'Content-type: multipart/form-data; boundary=' . $boundary . "\r\n";
$query .= 'Connection: Keep-Alive' . "\r\n";
$query .= 'Content-Length: ' . strlen($body) . "\r\n";
$query .= "Accept:*/*\r\n\r\n";
$query .= $body;


$result = fwrite($sp, $query . "\r\n");
$result2 = fread($sp, 10000000);
//var_dump($result, $result2);

==> ts-pfsense_1.05-02.tar.gz: ts-pfsense/tslogupload.php <==
<?php
/**
 *
 * Copyright(c) 2006-2018 ThreatSTOP, Inc. All Rights Reserved
 *
 * NOTICE: All information contained herein is, and remains the property
 * of ThreatSTOP, Inc. and its suppliers, if any. The intellectual and 
 * technical concepts contained herein are proprietary to ThreatSTOP, Inc. 
 * and its suppliers and certain aspects thereof are protected by United 
 * States Patent No. 8,533,822 and United States Patent No. 8,869,237, 
 * and are protected by trade secret or copyright law.
 *
 * US Government Entities: The ThreatSTOP service, software and
 * documentation, as applicable, are "commercial computer software" and
 * "commercial computer software documentation" developed exclusively at
 * private expense by Threatstop, Inc. ("Threatstop"). Pursuant to FAR
 * 12.212 or DFARS 227 7202 and their successors, as applicable, use,
 * reproduction and disclosure of the software and documentation is
 * governed by the terms of Threatstop's commercial agreement.
 */

require_once("/usr/local/www/threatstop.conf.php"); // TDID

$content    = shell_exec("%clog% $argv[1]");
//$content    = shell_exec("$(which clog) $argv[1]");
shell_exec('/usr/bin/logger -p local0.info "ThreatSTOP log upload"');
$startpos = strrpos("ThreatSTOP log upload", $content);
if ($startpos) {
	$content = substr($content, $startpos);
}
$ip      = 'ssl://logs.threatstop.com';
$host    = 'logs.threatstop.com';
$md5     = md5($content);
$len     = strlen($content);

# Don't upload if no log present
if ($len == 0) {
	exit;
}

//echo "$md5 $len\n";
$sp = fsockopen($ip, 443, $errno, $errstr, 10);

if (!$sp) {
	die("error: $errstr ($errno)" . "\r\n");
}

$boundary = str_repeat('-', 10) . time();

$body = '--' . $boundary . "\r\n";
$body .= "Content-Disposition: form-data; name=\"md5_client\"\r\n\r\n";
$body .= $md5."\r\n";
$body .= '--' . $boundary . "\r\n";
$body .= "Content-Disposition: form-data; name=\"upfile_size\"\r\n\r\n";
$body .= "$len\r\n";
$body .= '--' . $boundary . "\r\n";
if ($TDID) {
  $body .= "Content-Disposition: form-data; name=\"fw_tdid\"\r\n\r\n";
  $body .= "$TDID\r\n";
  $body .= '--' . $boundary . "\r\n";
}
//$body .= "Content-Disposition: form-data; name=\"fw_ip\"\r\n\r\n";
//$body .= $ip"\r\n";
//$body .= '--' . $boundary . "\r\n";
$body .= "Content-Disposition: form-data; name=\"upfile\"; filename=\"log\"\r\n";
$body .= "Content-Type: text/plain\r\n";
$body .= "Content-Transfer-Encoding: binary\r\n\r\n";
$body .= $content . "\r\n";
$body .= "--$boundary--\r\n";

$query  = 'POST /cgi-bin/logupload.pl HTTP/1.1' . "\r\n";
$query .= 'HOST: ' . $host . "\r\n";
$query .= 'Content-type: multipart/form-data; boundary=' . $boundary . "\r\n";
$query .= 'Connection: Keep-Alive' . "\r\n";
$query .= 'Content-Length: ' . strlen($body) . "\r\n";
$query .= "Accept:*/*\r\n\r\n";
$query .= $body;

$result = fwrite($sp, $query . "\r\n");
$result2 = fread($sp, 10000000);
//var_dump($result, $result2);
